@@ -22,15 +22,21 @@
 
 #ifndef GSH_FILE_DIALOG
 #define GSH_FILE_DIALOG
-void
-     gsh_file_dialog(struct GSH * gsh, GtkFileChooserAction action);
-void
-     gsh_file_open_dialog(struct GSH * gsh);
-void
-     gsh_file_save_dialog(struct GSH * gsh);
-void
-     gsh_folder_open_dialog(struct GSH * gsh);
-void
-     gsh_folder_create_dialog(struct GSH * gsh);
 
-#endif
+void
+gsh_file_dialog(struct GSH * gsh, 
+		GtkFileChooserAction action) __attribute__((noreturn));
+
+void
+gsh_file_open_dialog(struct GSH * gsh) __attribute__((noreturn));
+
+void
+gsh_file_save_dialog(struct GSH * gsh) __attribute__((noreturn));
+
+void
+gsh_folder_open_dialog(struct GSH * gsh) __attribute__((noreturn));
+
+void
+gsh_folder_create_dialog(struct GSH * gsh) __attribute__((noreturn));
+
+#endif /* !GSH_FILE_DIALOG */
